@@ -27,24 +27,38 @@ setMethod('gpuMatrix',
           signature(data = 'matrix'),
           function(data, type=NULL, ctx_id = NULL){
               
-              if (is.null(type)) {
-                  type <- switch(typeof(data),
-                                 "integer" = "integer",
-                                 getOption("gpuR.default.type"))
+              if (is.null(type)){
+                  if(typeof(data) == "integer") {
+                      type <- "integer"
+                  }else{
+                      type <- getOption("gpuR.default.type")    
+                  }
               }
               
-              device <- currentDevice()
+              if(type == "complex"){
+                  warning("default complex type is double (dcomplex)")
+                  type <- 'dcomplex'
+              }
+              
+              device <- if(is.null(ctx_id)) currentDevice() else listContexts()[ctx_id,]
               
               context_index <- ifelse(is.null(ctx_id), currentContext(), as.integer(ctx_id))
-              device_index <- as.integer(device$device_index)
+              device_index <- if(is.null(ctx_id)) as.integer(device$device_index) else device$device_index + 1L
+              
+              platform_index <- if(is.null(ctx_id)) currentPlatform()$platform_index else device$platform_index + 1L
+              platform_name <- platformInfo(platform_index)$platformName
+              
               device_type <- device$device_type
               device_name <- switch(device_type,
-                                    "gpu" = gpuInfo(device_idx = as.integer(device_index))$deviceName,
-                                    "cpu" = cpuInfo(device_idx = as.integer(device_index))$deviceName,
+                                    "gpu" = gpuInfo(
+                                        device_idx = as.integer(device_index),
+                                        context_idx = context_index)$deviceName,
+                                    "cpu" = cpuInfo(
+                                        device_idx = as.integer(device_index),
+                                        context_idx = context_index)$deviceName,
                                     stop("Unrecognized device type")
               )
-              platform_index <- currentPlatform()$platform_index
-              platform_name <- platformInfo(platform_index)$platformName
+              
               
               data = switch(type,
                             integer = {
@@ -52,7 +66,8 @@ setMethod('gpuMatrix',
                                     address=getRmatEigenAddress(data, 
                                                             nrow(data),
                                                             ncol(data), 
-                                                            4L),
+                                                            4L, 
+                                                            context_index - 1L),
                                     .context_index = context_index,
                                     .platform_index = platform_index,
                                     .platform = platform_name,
@@ -64,7 +79,8 @@ setMethod('gpuMatrix',
                                     address=getRmatEigenAddress(data, 
                                                             nrow(data),
                                                             ncol(data), 
-                                                            6L),
+                                                            6L, 
+                                                            context_index - 1L),
                                     .context_index = context_index,
                                     .platform_index = platform_index,
                                     .platform = platform_name,
@@ -72,12 +88,40 @@ setMethod('gpuMatrix',
                                     .device = device_name)
                             },
                             double = {
-                                assert_has_double(platform_index, device_index)
+                                assert_has_double(device_index, context_index)
                                 new("dgpuMatrix",
                                     address = getRmatEigenAddress(data, 
                                                               nrow(data),
                                                               ncol(data), 
-                                                              8L),
+                                                              8L, 
+                                                              context_index - 1L),
+                                    .context_index = context_index,
+                                    .platform_index = platform_index,
+                                    .platform = platform_name,
+                                    .device_index = device_index,
+                                    .device = device_name)
+                            },
+                            fcomplex = {
+                                new("cgpuMatrix",
+                                    address = getRmatEigenAddress(data, 
+                                                                  nrow(data),
+                                                                  ncol(data), 
+                                                                  10L, 
+                                                                  context_index - 1L),
+                                    .context_index = context_index,
+                                    .platform_index = platform_index,
+                                    .platform = platform_name,
+                                    .device_index = device_index,
+                                    .device = device_name)
+                            },
+                            dcomplex = {
+                                assert_has_double(device_index, context_index)
+                                new("zgpuMatrix",
+                                    address = getRmatEigenAddress(data, 
+                                                                  nrow(data),
+                                                                  ncol(data), 
+                                                                  12L, 
+                                                                  context_index - 1L),
                                     .context_index = context_index,
                                     .platform_index = platform_index,
                                     .platform = platform_name,
@@ -104,23 +148,29 @@ setMethod('gpuMatrix',
               assert_is_numeric(nrow)
               assert_is_numeric(ncol)
               
-              device <- currentDevice()
+              device <- if(is.null(ctx_id)) currentDevice() else listContexts()[ctx_id,]
               
               context_index <- ifelse(is.null(ctx_id), currentContext(), as.integer(ctx_id))
-              device_index <- as.integer(device$device_index)
+              device_index <- if(is.null(ctx_id)) as.integer(device$device_index) else device$device_index + 1L
+              
+              platform_index <- if(is.null(ctx_id)) currentPlatform()$platform_index else device$platform_index + 1L
+              platform_name <- platformInfo(platform_index)$platformName
+              
               device_type <- device$device_type
               device_name <- switch(device_type,
-                                    "gpu" = gpuInfo(device_idx = as.integer(device_index))$deviceName,
-                                    "cpu" = cpuInfo(device_idx = as.integer(device_index))$deviceName,
+                                    "gpu" = gpuInfo(
+                                        device_idx = as.integer(device_index),
+                                        context_idx = context_index)$deviceName,
+                                    "cpu" = cpuInfo(
+                                        device_idx = as.integer(device_index),
+                                        context_idx = context_index)$deviceName,
                                     stop("Unrecognized device type")
               )
-              platform_index <- currentPlatform()$platform_index
-              platform_name <- platformInfo(platform_index)$platformName
               
               data = switch(type,
                             integer = {
                                 new("igpuMatrix", 
-                                    address=emptyEigenXptr(nrow, ncol, 4L),
+                                    address=emptyEigenXptr(nrow, ncol, 4L, context_index - 1L),
                                     .context_index = context_index,
                                     .platform_index = platform_index,
                                     .platform = platform_name,
@@ -129,7 +179,7 @@ setMethod('gpuMatrix',
                             },
                             float = {
                                 new("fgpuMatrix", 
-                                    address=emptyEigenXptr(nrow, ncol, 6L),
+                                    address=emptyEigenXptr(nrow, ncol, 6L, context_index - 1L),
                                     .context_index = context_index,
                                     .platform_index = platform_index,
                                     .platform = platform_name,
@@ -137,9 +187,9 @@ setMethod('gpuMatrix',
                                     .device = device_name)
                             },
                             double = {
-                                assert_has_double(platform_index, device_index)
+                                assert_has_double(device_index, context_index)
                                 new("dgpuMatrix",
-                                    address = emptyEigenXptr(nrow, ncol, 8L),
+                                    address = emptyEigenXptr(nrow, ncol, 8L, context_index - 1L),
                                     .context_index = context_index,
                                     .platform_index = platform_index,
                                     .platform = platform_name,
@@ -167,25 +217,31 @@ setMethod('gpuMatrix',
               assert_is_numeric(nrow)
               assert_is_numeric(ncol)
               
-              device <- currentDevice()
+              device <- if(is.null(ctx_id)) currentDevice() else listContexts()[ctx_id,]
               
               context_index <- ifelse(is.null(ctx_id), currentContext(), as.integer(ctx_id))
-              device_index <- as.integer(device$device_index)
+              device_index <- if(is.null(ctx_id)) as.integer(device$device_index) else device$device_index + 1L
+              
+              platform_index <- if(is.null(ctx_id)) currentPlatform()$platform_index else device$platform_index + 1L
+              platform_name <- platformInfo(platform_index)$platformName
+              
               device_type <- device$device_type
               device_name <- switch(device_type,
-                                    "gpu" = gpuInfo(device_idx = as.integer(device_index))$deviceName,
-                                    "cpu" = cpuInfo(device_idx = as.integer(device_index))$deviceName,
+                                    "gpu" = gpuInfo(
+                                        device_idx = as.integer(device_index),
+                                        context_idx = context_index)$deviceName,
+                                    "cpu" = cpuInfo(
+                                        device_idx = as.integer(device_index),
+                                        context_idx = context_index)$deviceName,
                                     stop("Unrecognized device type")
               )
-              platform_index <- currentPlatform()$platform_index
-              platform_name <- platformInfo(platform_index)$platformName
               
               if(length(data) > 1){
                   data = switch(type,
                                 integer = stop("Cannot create integer gpuMatrix from numeric"),
                                 float = {
                                     new("fgpuMatrix", 
-                                        address=sexpVecToEigenXptr(data, nrow, ncol, 6L),
+                                        address=sexpVecToEigenXptr(data, nrow, ncol, 6L, context_index - 1L),
                                         .context_index = context_index,
                                         .platform_index = platform_index,
                                         .platform = platform_name,
@@ -193,9 +249,9 @@ setMethod('gpuMatrix',
                                         .device = device_name)
                                 },
                                 double = {
-                                    assert_has_double(platform_index, device_index)
+                                    assert_has_double(device_index, context_index)
                                     new("dgpuMatrix",
-                                        address = sexpVecToEigenXptr(data, nrow, ncol, 8L),
+                                        address = sexpVecToEigenXptr(data, nrow, ncol, 8L, context_index - 1L),
                                         .context_index = context_index,
                                         .platform_index = platform_index,
                                         .platform = platform_name,
@@ -210,7 +266,7 @@ setMethod('gpuMatrix',
                                 integer = stop("Cannot create integer gpuMatrix from numeric"),
                                 float = {
                                     new("fgpuMatrix", 
-                                        address=initScalarEigenXptr(data, nrow, ncol, 6L),
+                                        address=initScalarEigenXptr(data, nrow, ncol, 6L, context_index - 1L),
                                         .context_index = context_index,
                                         .platform_index = platform_index,
                                         .platform = platform_name,
@@ -218,9 +274,9 @@ setMethod('gpuMatrix',
                                         .device = device_name)
                                 },
                                 double = {
-                                    assert_has_double(platform_index, device_index)
+                                    assert_has_double(device_index, context_index)
                                     new("dgpuMatrix",
-                                        address = initScalarEigenXptr(data, nrow, ncol, 8L),
+                                        address = initScalarEigenXptr(data, nrow, ncol, 8L, context_index - 1L),
                                         .context_index = context_index,
                                         .platform_index = platform_index,
                                         .platform = platform_name,
@@ -248,24 +304,30 @@ setMethod('gpuMatrix',
               assert_is_numeric(nrow)
               assert_is_numeric(ncol)
               
-              device <- currentDevice()
+              device <- if(is.null(ctx_id)) currentDevice() else listContexts()[ctx_id,]
               
               context_index <- ifelse(is.null(ctx_id), currentContext(), as.integer(ctx_id))
-              device_index <- as.integer(device$device_index)
+              device_index <- if(is.null(ctx_id)) as.integer(device$device_index) else device$device_index + 1L
+              
+              platform_index <- if(is.null(ctx_id)) currentPlatform()$platform_index else device$platform_index + 1L
+              platform_name <- platformInfo(platform_index)$platformName
+              
               device_type <- device$device_type
               device_name <- switch(device_type,
-                                    "gpu" = gpuInfo(device_idx = as.integer(device_index))$deviceName,
-                                    "cpu" = cpuInfo(device_idx = as.integer(device_index))$deviceName,
+                                    "gpu" = gpuInfo(
+                                        device_idx = as.integer(device_index),
+                                        context_idx = context_index)$deviceName,
+                                    "cpu" = cpuInfo(
+                                        device_idx = as.integer(device_index),
+                                        context_idx = context_index)$deviceName,
                                     stop("Unrecognized device type")
               )
-              platform_index <- currentPlatform()$platform_index
-              platform_name <- platformInfo(platform_index)$platformName
               
               if(length(data) > 1){
                   data = switch(type,
                                 integer = {
                                     new("igpuMatrix", 
-                                        address=sexpVecToEigenXptr(data, nrow, ncol, 4L),
+                                        address=sexpVecToEigenXptr(data, nrow, ncol, 4L, context_index - 1L),
                                         .context_index = context_index,
                                         .platform_index = platform_index,
                                         .platform = platform_name,
@@ -274,7 +336,7 @@ setMethod('gpuMatrix',
                                 },
                                 float = {
                                     new("fgpuMatrix", 
-                                        address=sexpVecToEigenXptr(data, nrow, ncol, 6L),
+                                        address=sexpVecToEigenXptr(data, nrow, ncol, 6L, context_index - 1L),
                                         .context_index = context_index,
                                         .platform_index = platform_index,
                                         .platform = platform_name,
@@ -282,9 +344,9 @@ setMethod('gpuMatrix',
                                         .device = device_name)
                                 },
                                 double = {
-                                    assert_has_double(platform_index, device_index)
+                                    assert_has_double(device_index, context_index)
                                     new("dgpuMatrix",
-                                        address = sexpVecToEigenXptr(data, nrow, ncol, 8L),
+                                        address = sexpVecToEigenXptr(data, nrow, ncol, 8L, context_index - 1L),
                                         .context_index = context_index,
                                         .platform_index = platform_index,
                                         .platform = platform_name,
@@ -298,7 +360,7 @@ setMethod('gpuMatrix',
                   data = switch(type,
                                 integer = {
                                     new("igpuMatrix", 
-                                        address=initScalarEigenXptr(data, nrow, ncol, 4L),
+                                        address=initScalarEigenXptr(data, nrow, ncol, 4L, context_index - 1L),
                                         .context_index = context_index,
                                         .platform_index = platform_index,
                                         .platform = platform_name,
@@ -307,7 +369,7 @@ setMethod('gpuMatrix',
                                 },
                                 float = {
                                     new("fgpuMatrix", 
-                                        address=initScalarEigenXptr(data, nrow, ncol, 6L),
+                                        address=initScalarEigenXptr(data, nrow, ncol, 6L, context_index - 1L),
                                         .context_index = context_index,
                                         .platform_index = platform_index,
                                         .platform = platform_name,
@@ -315,9 +377,9 @@ setMethod('gpuMatrix',
                                         .device = device_name)
                                 },
                                 double = {
-                                    assert_has_double(platform_index, device_index)
+                                    assert_has_double(device_index, context_index)
                                     new("dgpuMatrix",
-                                        address = initScalarEigenXptr(data, nrow, ncol, 8L),
+                                        address = initScalarEigenXptr(data, nrow, ncol, 8L, context_index - 1L),
                                         .context_index = context_index,
                                         .platform_index = platform_index,
                                         .platform = platform_name,
