@@ -7,13 +7,17 @@ current_context <- set_device_context("cpu")
 set.seed(123)
 
 ORDER <- 4
+ORDER_PAD <- 129
 
 # Base R objects
 Aint <- matrix(sample(seq(10), ORDER^2, replace=TRUE), nrow=ORDER, ncol=ORDER)
 Bint <- matrix(sample(seq(10), ORDER^2, replace=TRUE), nrow=ORDER, ncol=ORDER)
+AintPad <- matrix(sample(seq(10), ORDER*ORDER_PAD, replace=TRUE), nrow=ORDER, ncol=ORDER_PAD)
+BintPad <- matrix(sample(seq(10), ORDER*ORDER_PAD, replace=TRUE), nrow=ORDER_PAD, ncol = ORDER)
 A <- matrix(rnorm(ORDER^2), nrow=ORDER, ncol=ORDER)
 B <- matrix(rnorm(ORDER^2), nrow=ORDER, ncol=ORDER)
 E <- matrix(rnorm(15), nrow=5)
+v <- rnorm(ORDER)
 
 # Single Precision tests
 
@@ -48,6 +52,26 @@ test_that("CPU gpuMatrix Single Precision Matrix multiplication", {
                  info="float matrix elements not equivalent")  
 })
 
+test_that("CPU gpuMatrix Single Precision Matrix-Vector multiplication", {
+    
+    has_cpu_skip()
+    
+    C <- A %*% v
+    C2 <- v %*% B
+    
+    fgpuA <- gpuMatrix(A, type="float")
+    fgpuB <- gpuMatrix(B, type="float")
+    fgpuV <- gpuVector(v, type = "float")
+    
+    fgpuC <- fgpuA %*% fgpuV
+    fgpuC2 <- fgpuV %*% fgpuB
+    
+    expect_equal(fgpuC[,], c(C), tolerance=1e-06, 
+                 info="float matrix elements not equivalent")  
+    expect_equal(fgpuC2[,], c(C2), tolerance=1e-06, 
+                 info="float matrix elements not equivalent")  
+})
+
 test_that("CPU gpuMatrix Single Precision Matrix Subtraction", {
     
     has_cpu_skip()
@@ -477,9 +501,12 @@ test_that("CPU gpuMatrix Integer Matrix multiplication", {
     has_cpu_skip()
     
     Cint <- Aint %*% Bint
+    CintPad <- AintPad %*% BintPad
     
     igpuA <- gpuMatrix(Aint, type="integer")
     igpuB <- gpuMatrix(Bint, type="integer")
+    igpuApad <- gpuMatrix(AintPad, type="integer")
+    igpuBpad <- gpuMatrix(BintPad, type="integer")
     
     igpuC <- igpuA %*% igpuB
     
@@ -495,6 +522,11 @@ test_that("CPU gpuMatrix Integer Matrix multiplication", {
     
     expect_equivalent(igpuC[,], Cint,
                       info="integer matrix elements not equivalent")
+    
+    igpuCpad <- igpuApad %*% igpuBpad
+    
+    expect_equivalent(igpuCpad[], CintPad,
+                      info = "padded rectangular matrix elements not equivalent")
 })
 
 test_that("CPU gpuMatrix Integer Matrix Subtraction", {
@@ -793,6 +825,26 @@ test_that("CPU gpuMatrix Double Precision Matrix multiplication", {
                  info="double matrix elements not equivalent")  
 })
 
+test_that("CPU gpuMatrix Double Precision Matrix-Vector multiplication", {
+    
+    has_cpu_skip()
+    
+    C <- A %*% v
+    C2 <- v %*% B
+    
+    fgpuA <- gpuMatrix(A, type="double")
+    fgpuB <- gpuMatrix(B, type="double")
+    fgpuV <- gpuVector(v, type = "double")
+    
+    fgpuC <- fgpuA %*% fgpuV
+    fgpuC2 <- fgpuV %*% fgpuB
+    
+    expect_equal(fgpuC[,], c(C), tolerance=.Machine$double.eps^0.5,
+                 info="double matrix elements not equivalent")
+    expect_equal(fgpuC2[,], c(C2), tolerance=.Machine$double.eps^0.5,
+                 info="double matrix elements not equivalent")
+})
+
 test_that("CPU gpuMatrix Double Precision Matrix Subtraction", {
     
     has_cpu_skip()
