@@ -97,31 +97,31 @@ test_that("CPU gpuMatrix Double Precision Matrix Element-Wise Trignometry", {
     
     expect_is(fgpuC, "dgpuMatrix")    
     expect_equal(fgpuS[,], Sin, tolerance=.Machine$double.eps ^ 0.5,
-                 info="sin float matrix elements not equivalent",
+                 info="sin matrix elements not equivalent",
                  check.attributes=FALSE)  
     expect_equal(fgpuAS[,], Asin, tolerance=.Machine$double.eps ^ 0.5,
-                 info="arc sin float matrix elements not equivalent",
+                 info="arc sin matrix elements not equivalent",
                  check.attributes=FALSE)  
     expect_equal(fgpuHS[,], Hsin, tolerance=.Machine$double.eps ^ 0.5, 
-                 info="hyperbolic sin float matrix elements not equivalent",
+                 info="hyperbolic sin matrix elements not equivalent",
                  check.attributes=FALSE)  
     expect_equal(fgpuC[,], Cos, tolerance=.Machine$double.eps ^ 0.5,
-                 info="cos float matrix elements not equivalent",
+                 info="cos matrix elements not equivalent",
                  check.attributes=FALSE)    
     expect_equal(fgpuAC[,], Acos, tolerance=.Machine$double.eps ^ 0.5, 
-                 info="arc cos float matrix elements not equivalent",
+                 info="arc cos matrix elements not equivalent",
                  check.attributes=FALSE)    
     expect_equal(fgpuHC[,], Hcos, tolerance=.Machine$double.eps ^ 0.5, 
-                 info="hyperbolic cos float matrix elements not equivalent",
+                 info="hyperbolic cos matrix elements not equivalent",
                  check.attributes=FALSE)  
     expect_equal(fgpuT[,], Tan, tolerance=.Machine$double.eps ^ 0.5,
-                 info="tan float matrix elements not equivalent",
+                 info="tan matrix elements not equivalent",
                  check.attributes=FALSE)  
     expect_equal(fgpuAT[,], Atan, tolerance=.Machine$double.eps ^ 0.5, 
-                 info="arc tan float matrix elements not equivalent",
+                 info="arc tan matrix elements not equivalent",
                  check.attributes=FALSE)  
     expect_equal(fgpuHT[,], Htan, tolerance=.Machine$double.eps ^ 0.5, 
-                 info="hyperbolic tan float matrix elements not equivalent",
+                 info="hyperbolic tan matrix elements not equivalent",
                  check.attributes=FALSE) 
 })
 
@@ -171,13 +171,13 @@ test_that("CPU gpuMatrix Double Precision Matrix Element-Wise Logs", {
     expect_is(fgpu_log10, "dgpuMatrix")
     expect_is(fgpu_log2, "dgpuMatrix")
     expect_equal(fgpu_log[,], R_log, tolerance=.Machine$double.eps ^ 0.5, 
-                 info="log float matrix elements not equivalent",
+                 info="log matrix elements not equivalent",
                  check.attributes=FALSE)  
     expect_equal(fgpu_log10[,], R_log10, tolerance=.Machine$double.eps ^ 0.5, 
-                 info="log10 float matrix elements not equivalent",
+                 info="log10 matrix elements not equivalent",
                  check.attributes=FALSE)  
     expect_equal(fgpu_log2[,], R_log2, tolerance=.Machine$double.eps ^ 0.5, 
-                 info="base log float matrix elements not equivalent",
+                 info="base log matrix elements not equivalent",
                  check.attributes=FALSE) 
 })
 
@@ -374,6 +374,22 @@ test_that("CPU gpuMatrix Double Precision Matrix sqrt", {
                  check.attributes=FALSE)  
 })
 
+# test_that("CPU gpuMatrix Integer Precision Matrix sign", {
+#     has_cpu_skip()
+#     
+#     Ai <- matrix(seq.int(16), 4, 4) * sample(c(-1, 1), 16, replace = TRUE)
+#     R_sign <- sign(Ai)
+#     
+#     fgpuA <- gpuMatrix(Ai, type="integer")
+#     
+#     fgpu_sign <- sign(fgpuA)
+#     
+#     expect_is(fgpu_sign, "igpuMatrix")
+#     expect_equivalent(fgpu_sign[,], R_sign, 
+#                  info="sign integer matrix elements not equivalent",
+#                  check.attributes=FALSE)  
+# })
+
 test_that("CPU gpuMatrix Single Precision Matrix sign", {
     has_cpu_skip()
     
