@@ -35,7 +35,7 @@ test_that("gpuMatrix Single Precision Matrix Square Matrix Inversion",
 
               # print("completed")
 
-              expect_is(ginv, "fvclMatrix")
+              expect_is(ginv, "fgpuMatrix")
 
               # print("R matrix")
               # print(rinv)
@@ -108,7 +108,7 @@ test_that("gpuMatrix Double Precision Matrix Square Matrix Inversion",
 
               ginv <- solve(fgpuX)
 
-              expect_is(ginv, "dvclMatrix")
+              expect_is(ginv, "dgpuMatrix")
 
               expect_equal(fgpuX[], X, tolerance = .Machine$double.eps ^ 0.5,
                            info = "input matrix was overwritten")
