@@ -1,6 +1,12 @@
 library(gpuR)
 context("vclMatrix Distance Computations")
 
+if(detectGPUs() >= 1){
+    current_context <- set_device_context("gpu")    
+}else{
+    current_context <- currentContext()
+}
+
 # set seed
 set.seed(123)
 
@@ -316,3 +322,5 @@ test_that("vclMatrix Integer Precision Pairwise Squared Euclidean Distance",
               #              check.attributes=FALSE) 
           })
 
+setContext(current_context)
+
